# AiiDA RASPA2 plugin

`aiida-raspa` allows you to run calculations with the [RASPA2 code](https://github.com/numat/RASPA2)
using [AiiDA](https://www.aiida.net).

Installation
============

```
$ git clone https://github.com/yakutovicha/aiida-raspa
$ cd aiida-raspa
$ pip install -e .  # also installs aiida, if missing (but not postgres)
$ reentry scan -r aiida  
```
